@@ -26,8 +26,22 @@ class MinutesField(forms.IntegerField):
             error_messages = {}
         if not 'invalid' in error_messages:
             error_messages['invalid'] = _(u'Enter a valid value.')
+        if not 'max_value' in error_messages:
+            msg = _(u'Enter a value of maximum %(total)d minutes')
+            error_messages['max_value'] = msg
         kwargs['error_messages'] = error_messages
         super(MinutesField, self).__init__(*args, **kwargs)
+        
+    def _validate_max_value(self, total):
+        if self.max_value and total > self.max_value:
+            (hours, minutes) = MinutesWidget.divide(self.max_value)
+            msg = self.error_messages['max_value']
+            raise forms.ValidationError(msg % {
+                'hours': hours,
+                'minutes': minutes,
+                'total': total
+            })
+        return total
 
     def clean(self, value):
         if not value:
@@ -41,7 +55,7 @@ class MinutesField(forms.IntegerField):
             if minutes > 59:
                 msg = self.error_messages['invalid']
                 raise forms.ValidationError(msg)
-            value = (hours * 60) + minutes
+            value = self._validate_max_value((hours * 60) + minutes)
         else:
             value = value.replace(',', '.')
             if not '.' in value:
@@ -55,7 +69,8 @@ class MinutesField(forms.IntegerField):
                     raise forms.ValidationError(msg)
                 if fraction == 5:
                     fraction = 50
-                value = int((hours * 60) + (60 / 100 * fraction))
+                minutes = (60 / 100 * fraction)
+                value = self._validate_max_value(int((hours * 60) + minutes))
             except (ValueError, TypeError):
                 msg = self.error_messages['invalid']
                 raise forms.ValidationError(msg)
